@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2105';
+our $VERSION = '0.2200';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -461,17 +461,8 @@ sub play
     # Allow for alternate strategies
     $self->{$_} = $strategies{$_} for keys %strategies;
 
-    my $player  = 1;
-    my $keys    = [ sort keys %{ $self->{$player} } ];
-    my $weights = [ map { $self->{$player}{$_} } @$keys ];
-    $weights = [ 1, 1 ] if 0 == sum0 @$weights;
-    my $rplay   = choose_weighted( $keys, $weights );
-
-    $player   = 2;
-    $keys     = [ sort keys %{ $self->{$player} } ];
-    $weights  = [ map { $self->{$player}{$_} } @$keys ];
-    $weights  = [ 1, 1 ] if 0 == sum0 @$weights;
-    my $cplay = choose_weighted( $keys, $weights );
+    my $rplay = $self->_player_move(1);
+    my $cplay = $self->_player_move(2);
 
     $play->{ "$rplay,$cplay" } = exists $self->{payoff} && $self->{payoff}
         ? $self->{payoff}[$rplay - 1][$cplay - 1]
@@ -480,6 +471,18 @@ sub play
     return $play;
 }
 
+sub _player_move {
+    my ( $self, $player ) = @_;
+
+    my $keys    = [ sort keys %{ $self->{$player} } ];
+    my $weights = [ map { $self->{$player}{$_} } @$keys ];
+
+    # Handle the [0, 0, ...] edge case
+    $weights = [ (1) x @$weights ] if 0 == sum0 @$weights;
+
+    return choose_weighted( $keys, $weights );
+}
+
 1;
 
 __END__
@@ -494,7 +497,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2105
+version 0.2200
 
 =head1 SYNOPSIS
 
@@ -574,8 +577,8 @@ And in this implementation that would be:
     payoff2 => [ [ -1,  0 ], [ -3, -2 ] ],  # Red:  [ R2, T2 ], [ S2, P2 ]
  );
 
-Where the two player strategies are to either Cooperate or Defect.  This is
-given by a hash for each of the two players:
+Where the two player strategies are to either Cooperate (1) or Defect (2).  This
+is given by a hash for each of the two players, where the values are Boolean:
 
  %strategy = (
     1 => { 1 => $cooporate1, 2 => $defect1 }, # Blue
@@ -640,7 +643,7 @@ non-zero-sum game, given pure opponent strategies.
 
 =head2 saddlepoint()
 
- $p = $g->saddlepoint;
+ $s = $g->saddlepoint;
 
 Return the saddlepoint of a zero-sum game, or C<undef> if there is none.
 
@@ -690,8 +693,8 @@ for its row.
 
 =head2 play()
 
- $u = $g->play();
- $u = $g->play(%strategies);
+ $p = $g->play();
+ $p = $g->play(%strategies);
 
 Return a single outcome for a zero-sum game, or a pair for a non-zero-sum game
 as a hashref keyed by each strategy chosen and with values of the payoff(s)
